@@ -65,6 +65,11 @@ def running_in_ci():
     return bool(os.environ.get('CI'))
 
 
+def running_in_ci_with_conda():
+    """Return True if currently running under CI with conda packages."""
+    return running_in_ci() and os.environ.get('USE_CONDA', None) == 'true'
+
+
 def is_stable_version(version):
     """
     Return true if version is stable, i.e. with letters in the final component.
@@ -281,7 +286,7 @@ def get_conf_paths():
         search_paths = []
         tmpfolder = str(tempfile.gettempdir())
         for i in range(3):
-            path = os.path.join(tmpfolder, 'site-config-'+str(i))
+            path = os.path.join(tmpfolder, 'site-config-' + str(i))
             if not os.path.isdir(path):
                 os.makedirs(path)
             search_paths.append(path)
@@ -351,6 +356,7 @@ def is_pynsist():
         return pkgs_path in os.environ.get('PYTHONPATH')
     return False
 
+
 #==============================================================================
 # Translations
 #==============================================================================
@@ -375,6 +381,7 @@ LANGUAGE_CODES = {
 # Disabled languages because their translations are outdated or incomplete
 DISABLED_LANGUAGES = ['hu', 'pl']
 
+
 def get_available_translations():
     """
     List available translations for spyder based on the folders found in the
@@ -389,7 +396,7 @@ def get_available_translations():
     langs = [DEFAULT_LANGUAGE] + langs
 
     # Remove disabled languages
-    langs = list( set(langs) - set(DISABLED_LANGUAGES) )
+    langs = list(set(langs) - set(DISABLED_LANGUAGES))
 
     # Check that there is a language code available in case a new translation
     # is added, to ensure LANGUAGE_CODES is updated.
@@ -508,6 +515,7 @@ def get_translation(modname, dirname=None):
     try:
         _trans = gettext.translation(modname, locale_path, codeset="utf-8")
         lgettext = _trans.lgettext
+
         def translate_gettext(x):
             if not PY3 and is_unicode(x):
                 x = x.encode("utf-8")
@@ -520,6 +528,7 @@ def get_translation(modname, dirname=None):
     except Exception:
         return translate_dumb
 
+
 # Translation callback
 _ = get_translation("spyder")
 
@@ -529,23 +538,17 @@ _ = get_translation("spyder")
 #==============================================================================
 # Variable explorer display / check all elements data types for sequences:
 # (when saving the variable explorer contents, check_all is True,
-CHECK_ALL = False #XXX: If True, this should take too much to compute...
+CHECK_ALL = False  # XXX: If True, this should take too much to compute...
 
 EXCLUDED_NAMES = ['nan', 'inf', 'infty', 'little_endian', 'colorbar_doc',
                   'typecodes', '__builtins__', '__main__', '__doc__', 'NaN',
                   'Inf', 'Infinity', 'sctypes', 'rcParams', 'rcParamsDefault',
-                  'sctypeNA', 'typeNA', 'False_', 'True_',]
+                  'sctypeNA', 'typeNA', 'False_', 'True_']
 
 
 #==============================================================================
 # Mac application utilities
 #==============================================================================
-if PY3:
-    MAC_APP_NAME = 'Spyder.app'
-else:
-    MAC_APP_NAME = 'Spyder-Py2.app'
-
-
 def running_in_mac_app(pyexec=None):
     """
     Check if Python executable is located inside a standalone Mac app.
@@ -559,14 +562,46 @@ def running_in_mac_app(pyexec=None):
     if pyexec is None:
         pyexec = sys.executable
 
-    if sys.platform == "darwin":
-        if MAC_APP_NAME not in pyexec:
-            return False
+    bpath = get_mac_app_bundle_path()
+
+    if bpath and pyexec == osp.join(bpath, 'Contents/MacOS/python'):
         return True
     else:
         return False
 
 
+def get_mac_app_bundle_path():
+    """
+    Return the full path to the macOS app bundle. Otherwise return None.
+
+    EXECUTABLEPATH environment variable only exists if Spyder is a macOS app
+    bundle. In which case it will always end with
+    "/<app name>.app/Conents/MacOS/Spyder".
+    """
+    app_exe_path = os.environ.get('EXECUTABLEPATH', None)
+    if sys.platform == "darwin" and app_exe_path:
+        return osp.dirname(osp.dirname(osp.dirname(osp.abspath(app_exe_path))))
+    else:
+        return None
+
+
+# =============================================================================
+# Micromamba
+# =============================================================================
+def get_spyder_umamba_path():
+    """Return the path to the Micromamba executable bundled with Spyder."""
+    if running_in_mac_app():
+        path = osp.join(osp.dirname(osp.dirname(__file__)),
+                        'bin', 'micromamba')
+    elif is_pynsist():
+        path = osp.abspath(osp.join(osp.dirname(osp.dirname(__file__)),
+                                    'bin', 'micromamba.exe'))
+    else:
+        path = None
+
+    return path
+
+
 #==============================================================================
 # Reset config files
 #==============================================================================
