@@ -4,9 +4,6 @@
 # Licensed under the terms of the MIT License
 # (see spyder/__init__.py for details)
 
-# Standard library imports
-import sys
-
 # Third party imports
 from qtpy.QtCore import Signal
 from qtpy.QtWidgets import QAction
@@ -43,13 +40,12 @@ class PreferencesContainer(PluginMainContainer):
 
         def _dialog_finished(result_code):
             """Restore preferences dialog instance variable."""
+            self.dialog.disconnect()
             self.dialog = None
 
         if self.dialog is None:
             # TODO: Remove all references to main window
             dlg = ConfigDialog(main_window)
-            dlg.setStyleSheet("QTabWidget::tab-bar {"
-                                "alignment: left;}")
             self.dialog = dlg
 
             if prefs_dialog_size is not None:
@@ -91,9 +87,15 @@ class PreferencesContainer(PluginMainContainer):
         """Preference page index has changed."""
         self.dialog_index = index
 
-    def is_dialog_open(self):
+    def is_preferences_open(self):
+        """Check if preferences is open."""
         return self.dialog is not None and self.dialog.isVisible()
 
+    def close_preferences(self):
+        """Close preferences"""
+        if self.dialog is not None:
+            self.dialog.close()
+
     def show_preferences(self):
         """Show preferences."""
         self.sig_show_preferences_requested.emit()
